Replaced the word credit with pynt
authorNishanth Amuluru <nishanth@fossee.in>
Wed, 05 Jan 2011 22:30:45 +0530
changeset 219 f04a1ec7a07f
parent 218 59107ce0a618
child 220 807e4b701a20
Replaced the word credit with pynt
taskapp/events/task.py
taskapp/forms/task.py
taskapp/forms/user.py
taskapp/management/commands/seed_db.py
taskapp/models.py
taskapp/utilities/notification.py
taskapp/views/task.py
templates/about/admin.html
templates/about/task.html
templates/about/tasklife.html
templates/task/assigncredits.html
templates/task/assignpynts.html
templates/task/close.html
templates/task/complete.html
templates/task/view.html
templates/user/my_profile.html
urls.py
--- a/taskapp/forms/task.py	Wed Jan 05 22:22:10 2011 +0530
+++ b/taskapp/forms/task.py	Wed Jan 05 22:30:45 2011 +0530
@@ -4,7 +4,7 @@
 class TaskCreateForm(forms.ModelForm):
     class Meta:
         model = Task
-        fields = ['title', 'desc', 'tags_field', 'credits']
+        fields = ['title', 'desc', 'tags_field', 'pynts']
     #publish = forms.BooleanField(required=False)
 
     def clean_title(self):
@@ -25,7 +25,7 @@
 class EditTaskForm(forms.ModelForm):
     class Meta:
         model = Task
-        fields = ['title', 'desc', 'tags_field', 'credits']
+        fields = ['title', 'desc', 'tags_field', 'pynts']
 
     def clean_desc(self):
         data = self.cleaned_data['desc'].strip()
@@ -85,7 +85,7 @@
         task = forms.ChoiceField(choices=task_choices)
     return myForm()
 
-def AssignCreditForm(choices, instance=None):
+def AssignPyntForm(choices, instance=None):
     
     class myForm(forms.Form):
         user = forms.ChoiceField(choices=choices, required=True)
--- a/taskapp/forms/user.py	Wed Jan 05 22:22:10 2011 +0530
+++ b/taskapp/forms/user.py	Wed Jan 05 22:30:45 2011 +0530
@@ -16,7 +16,7 @@
     
     class Meta:
         model = Profile
-        exclude = ('user','rights','dob','credits')
+        exclude = ('user','rights','dob','pynts')
 
     def clean_photo(self):
         uploaded_photo = self.data.get('photo', None)
--- a/taskapp/management/commands/seed_db.py	Wed Jan 05 22:22:10 2011 +0530
+++ b/taskapp/management/commands/seed_db.py	Wed Jan 05 22:30:45 2011 +0530
@@ -43,9 +43,9 @@
         title = "Task "+str(i)
         desc = "I am "+title
         created_by = defaultReviewer
-        credits = 20
+        pynts = 20
         
-        task = taskEvents.createTask(title,desc,created_by,credits)
+        task = taskEvents.createTask(title,desc,created_by,pynts)
         if task:
             taskEvents.addReviewer(task, defaultReviewer)
             if i%2==0:taskEvents.publishTask(task)
--- a/taskapp/models.py	Wed Jan 05 22:22:10 2011 +0530
+++ b/taskapp/models.py	Wed Jan 05 22:30:45 2011 +0530
@@ -30,7 +30,7 @@
     ("DV", "Developer"),
     ("MG", "Manager"),
     ("AD", "Admin"),
-    ("PY", "Assign credits"),
+    ("PY", "Assign pynts"),
     ("CM", "Task completed"),
     ("CD", "Task closed"),
     ("DL", "Task deleted"),
@@ -70,7 +70,7 @@
     dob = models.DateField(verbose_name = u"Date of Birth", help_text = "YYYY-MM-DD")
     gender = models.CharField(max_length = 1, choices = GENDER_CHOICES)
     rights = models.CharField(max_length = 2, choices = RIGHTS_CHOICES, default = u"CT")
-    credits = models.PositiveSmallIntegerField(default = 0)
+    pynts = models.PositiveSmallIntegerField(default = 0)
     
     aboutme = models.TextField(blank = True)
     foss_comm = TagField(verbose_name="FOSS Communities")
@@ -94,7 +94,7 @@
     status = models.CharField(max_length = 2, choices = STATUS_CHOICES, default = "UP")
     tags_field = TagField(verbose_name = u"Tags", help_text = u"Give comma seperated tags") 
     
-    credits = models.PositiveSmallIntegerField(help_text = u"No.of credits a user gets on completing the task")
+    pynts = models.PositiveSmallIntegerField(help_text = u"No.of pynts a user gets on completing the task")
     progress = models.PositiveSmallIntegerField(default = 0)
         
     reviewers = models.ManyToManyField(User, related_name = "%(class)s_reviewers")
--- a/templates/about/admin.html	Wed Jan 05 22:22:10 2011 +0530
+++ b/templates/about/admin.html	Wed Jan 05 22:30:45 2011 +0530
@@ -3,6 +3,6 @@
     PyTasks - About - Admin
 {% endblock %}
 {% block content %}
-    Admin is the user who has to approve assign of credits to any user for his/her work on the task.<br />
+    Admin is the user who has to approve assign of pynts to any user for his/her work on the task.<br />
     An Admin also has the right to request normal users to become admins or managers or developers.
 {% endblock %}
--- a/templates/about/task.html	Wed Jan 05 22:22:10 2011 +0530
+++ b/templates/about/task.html	Wed Jan 05 22:30:45 2011 +0530
@@ -3,7 +3,7 @@
     PyTasks - About - Task
 {% endblock %}
 {% block content %}
-    A task is an entity that people can work on and get pynts for their work. Every task has credits which are given to
+    A task is an entity that people can work on and get pynts for their work. Every task has pynts which are given to
     users working on the task. A task is created by a privileged user and he becomes a 
     reviewer <sup><a href="/about/reviewer/" target="_blank">learn more</a></sup> for the task. 
     The task if open, can be claimed by other users if they would like to work on the task.<br /><br />
--- a/templates/about/tasklife.html	Wed Jan 05 22:22:10 2011 +0530
+++ b/templates/about/tasklife.html	Wed Jan 05 22:30:45 2011 +0530
@@ -22,9 +22,9 @@
      Also selecting a user to work on the task implies the task has all its dependencies satisfied.<br /><br />
      
      During the working stage of task, a reviewer can request assign of pynts to users working on task or the reviewers. The assign pynts link 
-     will be available to reviewer on the task page. If there are no users working, the reviewer can request assign of credits to himself
+     will be available to reviewer on the task page. If there are no users working, the reviewer can request assign of pynts to himself
      or one of the other reviewers, who ever has done work on the task. Even if there are no users working on task, if there is a 
-     request for assign of credits to the task implies that someone has worked on the task and hence dependencies cannot be 
+     request for assign of pynts to the task implies that someone has worked on the task and hence dependencies cannot be 
      added after that.<br /><br />
      
      The users can be selected to work or removed from working users at any point in time. If a user is removed, he can claim again
--- a/templates/task/assigncredits.html	Wed Jan 05 22:22:10 2011 +0530
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,42 +0,0 @@
-{% extends 'base.html' %}
-{% block title %}
-    {{task.title}}
-{% endblock %}
-{% block content %}
-        <a href="/task/view/tid={{task.id}}">Click here</a> to return to the task.<br />
-
-        <form action="" method="post">
-        {{form.as_p}}
-        <input type="submit" value="Submit">
-        </form>
-        {% if prev_credits %}
-            <a href="/task/complete/tid={{task.id}}">Mark task as complete.</a>
-            <hr />
-        {% endif %}
-        {% if credit_requests %}
-            <br/>Previous credits:<br />
-            {% for req in credit_requests %}
-            <hr />
-                <a href="/user/view/uid={{req.sent_by.id}}">{{req.sent_by.username}}</a> requested assigning of {{req.pynts}} pynts to
-                <a href="/user/view/uid={{req.receiving_user.id}}">{{req.receiving_user.username}}</a>
-                on {{req.creation_date|date:"D d M Y"}} at {{req.creation_date|time:"H:i"}}<br />
-                {% if req.is_replied %}
-                    status: 
-                    {% if req.reply %}
-                        Approved by <a href="/user/view/uid={{req.replied_by.id}}">{{req.replied_by.username}}</a>
-                        on {{req.reply_date|date:"D d M Y"}} at {{req.reply_date|time:"H:i"}}<br />
-                    {% else %}
-                        Rejected by <a href="/user/view/uid={{req.replied_by.id}}">{{req.replied_by.username}}</a>
-                        on {{req.reply_date|date:"D d M Y"}} at {{req.reply_date|time:"H:i"}}<br />
-                        {% if req.remarks %}
-                            Reason: {{req.remarks}}
-                        {% endif %}
-                    {% endif %}
-                {% else %}
-                    status: Request pending
-                {% endif %}
-            {% endfor %}
-        {% else %}
-            No assigning of pynts has been made for this task.
-        {% endif %}
-{% endblock %}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/templates/task/assignpynts.html	Wed Jan 05 22:30:45 2011 +0530
@@ -0,0 +1,42 @@
+{% extends 'base.html' %}
+{% block title %}
+    {{task.title}}
+{% endblock %}
+{% block content %}
+        <a href="/task/view/tid={{task.id}}">Click here</a> to return to the task.<br />
+
+        <form action="" method="post">
+        {{form.as_p}}
+        <input type="submit" value="Submit">
+        </form>
+        {% if prev_pynts %}
+            <a href="/task/complete/tid={{task.id}}">Mark task as complete.</a>
+            <hr />
+        {% endif %}
+        {% if pynt_requests %}
+            <br/>Previous pynts:<br />
+            {% for req in pynt_requests %}
+            <hr />
+                <a href="/user/view/uid={{req.sent_by.id}}">{{req.sent_by.username}}</a> requested assigning of {{req.pynts}} pynts to
+                <a href="/user/view/uid={{req.receiving_user.id}}">{{req.receiving_user.username}}</a>
+                on {{req.creation_date|date:"D d M Y"}} at {{req.creation_date|time:"H:i"}}<br />
+                {% if req.is_replied %}
+                    status: 
+                    {% if req.reply %}
+                        Approved by <a href="/user/view/uid={{req.replied_by.id}}">{{req.replied_by.username}}</a>
+                        on {{req.reply_date|date:"D d M Y"}} at {{req.reply_date|time:"H:i"}}<br />
+                    {% else %}
+                        Rejected by <a href="/user/view/uid={{req.replied_by.id}}">{{req.replied_by.username}}</a>
+                        on {{req.reply_date|date:"D d M Y"}} at {{req.reply_date|time:"H:i"}}<br />
+                        {% if req.remarks %}
+                            Reason: {{req.remarks}}
+                        {% endif %}
+                    {% endif %}
+                {% else %}
+                    status: Request pending
+                {% endif %}
+            {% endfor %}
+        {% else %}
+            No assigning of pynts has been made for this task.
+        {% endif %}
+{% endblock %}
--- a/templates/task/close.html	Wed Jan 05 22:22:10 2011 +0530
+++ b/templates/task/close.html	Wed Jan 05 22:30:45 2011 +0530
@@ -5,8 +5,8 @@
 {% block content %}
     <b>Disclaimer:</b><br />
     If a task is closed, it implies the task is no more a valid task. The task cannot be edited or added subtasks/dependencies.
-    Please <a href="/task/assigncredits/tid={{task.id}}">click here</a> to return to assign credits page if you want to request assign of credits.
-    You cannot request assign of credits and all the pending requests on this task will be made invalid when a task is closed.<br /><br />
+    Please <a href="/task/assignpynts/tid={{task.id}}">click here</a> to return to assign pynts page if you want to request assign of pynts.
+    You cannot request assign of pynts and all the pending requests on this task will be made invalid when a task is closed.<br /><br />
     
     The only difference between marking a task as closed and completed is that the tasks depending on completed tasks will be free to be claimed 
     and worked on. This action cannot be undone. If you have double checked every thing, please provide a reason and close the task.<br />
--- a/templates/task/complete.html	Wed Jan 05 22:22:10 2011 +0530
+++ b/templates/task/complete.html	Wed Jan 05 22:30:45 2011 +0530
@@ -5,13 +5,13 @@
 {% block content %}
     <b>Disclaimer:</b><br />
     Marking a task as complete implies the task has been completed successfully. It implies that all the required files 
-    are available as attatchments in comments and all the users worked on this task were credited accordingly.<br /><br />
+    are available as attatchments in comments and all the users worked on this task were pynted accordingly.<br /><br />
     This action sets the task as completed and frees all the tasks depending on this task. Henceforth, the task <strong>can not</strong> be 
     commented upon or edited by anyone.<br /><br />
-    If there are pending requests for assigning credits, they will be deleted and admins will not be able to approve those requests.
-    Hence you cannot assign credits to anyone for this task anymore. You must wait for the requests to be approved by any of the admins. 
-    If you would like to request for assigning more credits, return to assign credits page by clicking 
-    <a href="/task/assigncredits/tid={{task.id}}">here</a>.<br /><br />
+    If there are pending requests for assigning pynts, they will be deleted and admins will not be able to approve those requests.
+    Hence you cannot assign pynts to anyone for this task anymore. You must wait for the requests to be approved by any of the admins. 
+    If you would like to request for assigning more pynts, return to assign pynts page by clicking 
+    <a href="/task/assignpynts/tid={{task.id}}">here</a>.<br /><br />
     If you have double checked everything, confirm this action by clicking the button below.
     <form action="" method="post">
         <input value="Mark as Complete" type="submit">
--- a/templates/task/view.html	Wed Jan 05 22:22:10 2011 +0530
+++ b/templates/task/view.html	Wed Jan 05 22:30:45 2011 +0530
@@ -123,8 +123,8 @@
         <br />
     {% endif %}
     
-    {% if can_assign_credits %}
-        <a href="/task/assigncredits/tid={{task.id}}">View/Assign credits</a>
+    {% if can_assign_pynts %}
+        <a href="/task/assignpynts/tid={{task.id}}">View/Assign pynts</a>
     {% endif %}
     
     {% if task_claimable %}
--- a/templates/user/my_profile.html	Wed Jan 05 22:22:10 2011 +0530
+++ b/templates/user/my_profile.html	Wed Jan 05 22:30:45 2011 +0530
@@ -30,8 +30,8 @@
     {% if profile.dob %}
         <br><h4>Date of Birth</h4><hr>{{ profile.dob }}
     {% endif %}
-    {% if profile.credits %}
-        <br><h4>Credits</h4><hr>{{ profile.credits }}
+    {% if profile.pynts %}
+        <br><h4>Pynts</h4><hr>{{ profile.pynts }}
     {% endif %}
     {% if profile.foss_comm %}
         <br><h4>Foss Community</h4><hr>{{ profile.foss_comm }}
--- a/urls.py	Wed Jan 05 22:22:10 2011 +0530
+++ b/urls.py	Wed Jan 05 22:30:45 2011 +0530
@@ -34,7 +34,7 @@
     (r'^task/remuser/tid=(\w+)$', taskViews.rem_user),
     (r'^task/addtask/tid=(\w+)$', taskViews.add_tasks),
     (r'^task/remtask/tid=(\w+)$', taskViews.remove_task),
-    (r'^task/assigncredits/tid=(\w+)$', taskViews.assign_credits),
+    (r'^task/assignpynts/tid=(\w+)$', taskViews.assign_pynts),
     (r'^task/complete/tid=(\w+)$', taskViews.complete_task),
     (r'^task/close/tid=(\w+)$', taskViews.close_task),
     (r'^task/delete/tid=(\w+)$', taskViews.delete_task),
@@ -98,7 +98,7 @@
     (r'^task/remuser/tid=(\w+)$', taskViews.rem_user),
     (r'^task/addtask/tid=(\w+)$', taskViews.add_tasks),
     (r'^task/remtask/tid=(\w+)$', taskViews.remove_task),
-    (r'^task/assigncredits/tid=(\w+)$', taskViews.assign_credits),
+    (r'^task/assignpynts/tid=(\w+)$', taskViews.assign_pynts),
     (r'^task/complete/tid=(\w+)$', taskViews.complete_task),
     (r'^task/close/tid=(\w+)$', taskViews.close_task),
     (r'^task/delete/tid=(\w+)$', taskViews.delete_task),
--- a/taskapp/events/task.py	Wed Jan 05 22:22:10 2011 +0530
+++ b/taskapp/events/task.py	Wed Jan 05 22:30:45 2011 +0530
@@ -106,8 +106,8 @@
     task.save()
     return task     
 
-def createTask(title,desc,created_by,credits):
-    """ creates a bare minimum task with title, description and credits.
+def createTask(title,desc,created_by,pynts):
+    """ creates a bare minimum task with title, description and pynts.
     the creator of the task will be assigned as a reviewer for the task.
     """
 
@@ -128,7 +128,7 @@
     task.id = id 
     task.desc = desc
     task.created_by = created_by
-    task.credits = credits
+    task.pynts = pynts
     task.creation_datetime = datetime.now()
     task.published_datetime = datetime.now()
     task.save()
@@ -165,7 +165,7 @@
     create_notification("AU", added_user, assigned_by, task=task)
 
 
-def updateTask(task, title=None, desc=None, credits=None, tags_field=None):
+def updateTask(task, title=None, desc=None, pynts=None, tags_field=None):
     """ update the property accordingly.
     while updating title, check for uniqueness of title.
     return None if any error. 
@@ -178,7 +178,7 @@
         except Task.IntegrityError:
             return None
     if desc:task.desc = desc
-    if credits:task.credits = credits
+    if pynts:task.pynts = pynts
     if tags_field:task.tags_field = tags_field
     task.save()
     return task
@@ -204,7 +204,7 @@
     create_notification("RU", rem_user, removed_by, task=main_task, remarks=reason)
     ## TODO : create notification to the victim
 
-def assignCredits(task, given_by, given_to, points):
+def assignPynts(task, given_by, given_to, points):
     """ make a proper request object.
     """
     
--- a/taskapp/utilities/notification.py	Wed Jan 05 22:22:10 2011 +0530
+++ b/taskapp/utilities/notification.py	Wed Jan 05 22:30:45 2011 +0530
@@ -13,7 +13,7 @@
         reply: A boolean
         task: a task if applicable
         requested_by: a user makes the request
-            A reviewer who assigns credits in case of pynts
+            A reviewer who assigns pynts in case of pynts
             A reviewer who requests to act as a reviewer
         remarks: any remarks for rejecting
         receiving_user: user receiving pynts
@@ -32,18 +32,18 @@
         notification.pynts = pynts
 
         task_url= '<a href="/task/view/tid=%s">%s</a>'%(task.id, task.title)
-        credits_url = '<a href="/task/assigncredits/tid=%s">%s</a>'%(task.id, "click here")
+        pynts_url = '<a href="/task/assignpynts/tid=%s">%s</a>'%(task.id, "click here")
         reviewer_url = '<a href="/user/view/uid=%s">%s</a>'%(requested_by.id, requested_by.username)
         admin_url = '<a href="/user/view/uid=%s">%s</a>'%(sent_from.id, sent_from.username)
         user_url = '<a href="/user/view/uid=%s">%s</a>'%(receiving_user.id, receiving_user.username)
 
         if reply:
-            notification.sub = "Approved request for assign of credits for %s"%task.title[:20]
+            notification.sub = "Approved request for assign of pynts for %s"%task.title[:20]
             notification.message  = """ Request made by %s to assign %s pynts to %s for the task %s has been approved by %s<br />
                                     %s if you want the view/assign pynts page of the task.<br />"""%(reviewer_url, pynts, user_url, task_url, admin_url, credits_url)
 
         else:
-            notification.sub = "Rejected request for assign of credits for %s"%task.title[:20]
+            notification.sub = "Rejected request for assign of pynts for %s"%task.title[:20]
             notification.message = """ Request made by %s to assign %s pynts to %s for the task %s has been rejected by %s.<br /> """%(reviewer_url, pynts, user_url, task_url, admin_url)
             if remarks:
                 notification.remarks = remarks
@@ -177,7 +177,7 @@
 
         notification.sub = "Your claim for the task %s accepted."%task.title[:20]
         notification.message = "You have been selected to work on the task %s by %s.<br />"%(task_url, assigned_by_url)
-        notification.message += "You can now start working on the task and will be credited by the reviewers for your work.<br />"
+        notification.message += "You can now start working on the task and will be pynted by the reviewers for your work.<br />"
 
         notification.message += " Here is a list of reviewers for the task and their email addresses.<br /> <ul>"
         for a_reviewer in task.reviewers.all():
@@ -32,18 +32,18 @@
             notification.message  = """ Request made by %s to assign %s pynts to %s for the task %s has been approved by %s<br />
-                                    %s if you want the view/assign pynts page of the task.<br />"""%(reviewer_url, pynts, user_url, task_url, admin_url, credits_url)
+                                    %s if you want the view/assign pynts page of the task.<br />"""%(reviewer_url, pynts, user_url, task_url, admin_url, pynts_url)
 
         else:
--- a/taskapp/views/task.py	Wed Jan 05 22:22:10 2011 +0530
+++ b/taskapp/views/task.py	Wed Jan 05 22:30:45 2011 +0530
@@ -5,8 +5,8 @@
 
 from pytask.taskapp.models import User, Task, Comment, Request, Notification
 from pytask.taskapp.utilities.task import getTask
-from pytask.taskapp.forms.task import TaskCreateForm, AddReviewerForm, AddTaskForm, ChoiceForm, AssignCreditForm, RemoveUserForm, EditTaskForm, ClaimTaskForm
-from pytask.taskapp.events.task import createTask, reqReviewer, publishTask, addSubTask, addDep, addClaim, assignTask, updateTask, removeTask, removeUser, assignCredits, completeTask, closeTask, addReviewer, deleteTask
+from pytask.taskapp.forms.task import TaskCreateForm, AddReviewerForm, AddTaskForm, ChoiceForm, AssignPyntForm, RemoveUserForm, EditTaskForm, ClaimTaskForm
+from pytask.taskapp.events.task import createTask, reqReviewer, publishTask, addSubTask, addDep, addClaim, assignTask, updateTask, removeTask, removeUser, assignPynts, completeTask, closeTask, addReviewer, deleteTask
 from pytask.taskapp.views.user import show_msg
 from pytask.taskapp.utilities.user import get_user
 
@@ -113,7 +113,7 @@
     context['can_mod_reviewers'] = True if task.status in ["UP", "OP", "LO", "WR"] and is_reviewer else False
     context['can_mod_tasks'] = True if task.status in ["UP", "OP", "LO"] and is_reviewer else False
 
-    context['can_assign_credits'] = True if task.status in ["OP", "WR"] and is_reviewer else False
+    context['can_assign_pynts'] = True if task.status in ["OP", "WR"] and is_reviewer else False
     context['task_claimable'] = True if task.status in ["OP", "WR"] and not is_guest else False
 
     if task.status == "CD":
@@ -156,9 +156,9 @@
                     data = form.cleaned_data
                     title = data['title']
                     desc = data['desc']
-                    credits = data['credits']
+                    pynts = data['pynts']
                     #publish = data['publish'] # just in case if we have to show the option
-                    task = createTask(title,desc,user,credits)
+                    task = createTask(title,desc,user,pynts)
                     
                     addReviewer(task, user)
                     updateTask(task,tags_field=data['tags_field'])
@@ -486,11 +486,11 @@
     else:
         return show_msg(user, 'You are not authorised to perform this action', task_url, 'view the task')
 
-def assign_credits(request, tid):
-    """ Check if the user is a reviewer and credits can be assigned.
-    Then display all the approved credits.
-    Then see if reviewer can assign credits to users also or only reviewers.
-    Then put up a form for reviewer to assign credits accordingly.
+def assign_pynts(request, tid):
+    """ Check if the user is a reviewer and pynts can be assigned.
+    Then display all the approved pynts.
+    Then see if reviewer can assign pynts to users also or only reviewers.
+    Then put up a form for reviewer to assign pynts accordingly.
     """
     
     task_url = "/task/view/tid=%s"%tid
@@ -498,8 +498,8 @@
     user = get_user(request.user) if request.user.is_authenticated() else request.user
     task = getTask(tid)
 
     ## the moment we see that user had requested credits, it means he had worked and hence we change the status to WR
     ## we have to discuss on this since, credits may also be given to reviewer
     task.status = "WR"
     task.save()
 
@@ -511,35 +511,35 @@
             choices = [(_.id,_.username) for _ in task.reviewers.all()]
             if task.status == "WR":
                 choices.extend([(_.id, _.username) for _  in task.assigned_users.all() ])
-            prev_credits = task.request_task.filter(role="PY",is_valid=True,is_replied=True,reply=True).count()
-            credit_requests = task.request_task.filter(role="PY",is_valid=True).order_by('creation_date').reverse()
-            form = AssignCreditForm(choices)
+            prev_pynts = task.request_task.filter(role="PY",is_valid=True,is_replied=True,reply=True).count()
+            pynt_requests = task.request_task.filter(role="PY",is_valid=True).order_by('creation_date').reverse()
+            form = AssignPyntForm(choices)
 
             context = {
                 'user':user,
                 'task':task,
-                'prev_credits':prev_credits,
-                'credit_requests':credit_requests,
+                'prev_pynts':prev_pynts,
+                'pynt_requests':pynt_requests,
                 'form':form,
             }
 
             if request.method == "POST":
                 data = request.POST
-                form = AssignCreditForm(choices, data)
+                form = AssignPyntForm(choices, data)
                 if form.is_valid():
                     data = form.cleaned_data
                     uid = data['user']
                     points = data['pynts']
                     given_to = User.objects.get(id=uid)
-                    assignCredits(task=task, given_by=user, given_to=given_to, points=points)
-                    return redirect('/task/assigncredits/tid=%s'%task.id)
+                    assignPynts(task=task, given_by=user, given_to=given_to, points=points)
+                    return redirect('/task/assignpynts/tid=%s'%task.id)
                 else:
                     context['form'] = form
-                    return render_to_response('task/assigncredits.html', context)
+                    return render_to_response('task/assignpynts.html', context)
             else:
-                return render_to_response('task/assigncredits.html', context)
+                return render_to_response('task/assignpynts.html', context)
         else:
-            return show_msg(user, "Credits cannot be assigned at this stage", task_url, "view the task")
+            return show_msg(user, "Pynts cannot be assigned at this stage", task_url, "view the task")
     else:
         return show_msg(user, "You are not authorised to perform this action", task_url, "view the task")
 
@@ -587,8 +587,8 @@
     claimed_users = task.claimed_users.all()
     assigned_users = task.assigned_users.all()
 
-    assign_credits_url = '/task/assigncredits/tid=%s'%task.id
-    task_assigned_credits = task.credit_set.all()
+    assign_pynts_url = '/task/assignpynts/tid=%s'%task.id
+    task_assigned_pynts = task.pynt_set.all()
 
 
     if is_reviewer:
@@ -599,14 +599,14 @@
                 'task':task,
             }
 
-            if task_assigned_credits:
+            if task_assigned_pynts:
                 if request.method=="POST":
                     completeTask(task, user)
                     return redirect(task_url)
                 else:
                     return render_to_response('task/complete.html', context)
             else:
-                return show_msg(user, "Nobody has been credited for doing this task.", assign_credits_url, "assign credits")
+                return show_msg(user, "Nobody has been pynted for doing this task.", assign_pynts_url, "assign pynts")
         else:
             return show_msg(user, "The task cannot be marked as completed at this stage", task_url, "view the task")
     else:
@@ -498,8 +498,8 @@
     task = getTask(tid)
 
-    ## the moment we see that user had requested credits, it means he had worked and hence we change the status to WR
-    ## we have to discuss on this since, credits may also be given to reviewer
+    ## the moment we see that user had requested pynts, it means he had worked and hence we change the status to WR
+    ## we have to discuss on this since, pynts may also be given to reviewer
     task.status = "WR"
     task.save()